/*
 * GMSH script to generate a 2D star. It is parameterized to vary the number of
 * arms and size of the star.
 * 
 *
 * File:   makeStar2D.geo
 * Author: Kjetil A. Johannessen
 * Date:   November 2013
 *
 */

arms =   5;  // number of arms to the star
R    =   1;  // radius of outer points of the star
r    = 0.5;  // inner radius
lc   = 0.05; // characteristic size (element size)

dt = 2*Pi/arms/2;
For t In {0:arms-1}
	theta  = 2*Pi*t/arms;
	theta2 = theta + dt;
	pOut[t]  = newp; Point(pOut[t]) = {-R*Sin(theta),  R*Cos(theta),  0, lc};
	pIn[t]   = newp; Point(pIn[t])  = {-r*Sin(theta2), r*Cos(theta2), 0, lc};
	If(t>0)
		lin[2*t-1] = newl; Line(lin[2*t-1]) = {pIn[t-1], pOut[t]};
	EndIf
	lin[2*t] = newl; Line(lin[2*t]) = {pOut[t], pIn[t]};
EndFor
lin[2*arms-1] = newl; Line(lin[2*arms-1]) = {pIn[arms-1], pOut[0]};

Line Loop(100) = {lin[]};
Plane Surface(1000) = {100};
