/*
 * GMSH script to generate a 3D star. It is parameterized to vary the number of
 * arms and size of the star.
 * 
 *
 * File:   makeStar3D.geo
 * Author: Kjetil A. Johannessen
 * Date:   November 2013
 *
 */


arms =   7;  // number of arms to the star
R    =   1;  // radius of outer points of the star
r    = 0.5;  // inner radius
H    = 0.3;  // star height (at origin)
lc   = 0.05; // characteristic size (element size)




dt  = 2*Pi/arms/2;
top    = newp; Point(top)    = {0,0, H, lc};
bottom = newp; Point(bottom) = {0,0,-H, lc};
For t In {0:arms-1}
	theta  = 2*Pi*t/arms;
	theta2 = theta + dt;
	pOut[t]  = newp; Point(pOut[t]) = {-R*Sin(theta),  R*Cos(theta),  0, lc};
	pIn[t]   = newp; Point(pIn[t])  = {-r*Sin(theta2), r*Cos(theta2), 0, lc};
EndFor

For t In {0:arms-1}
	topLines[2*t]   = newl; Line(topLines[2*t])   = {top,    pOut[t]};
	topLines[2*t+1] = newl; Line(topLines[2*t+1]) = {top,    pIn[t]};
	botLines[2*t]   = newl; Line(botLines[2*t])   = {bottom, pOut[t]};
	botLines[2*t+1] = newl; Line(botLines[2*t+1]) = {bottom, pIn[t]};
EndFor

For t In {0:2*arms-1}
	nxtT   = t+1;
	If(t == 2*arms-1) nxtT = 0; EndIf
	acrossLin = newl; Line(acrossLin) = {t+pOut[0], nxtT+pOut[0]}; 
	lt[0] = acrossLin;
	lt[1] = -topLines[nxtT];
	lt[2] = topLines[t];
	ll   = newll; Line Loop(ll) = {lt[]};
	surf = news;  Plane Surface(surf) = {ll};
	allSurf[2*t] = surf;

	lb[0] = acrossLin;
	lb[1] = -botLines[nxtT];
	lb[2] = botLines[t];
	ll   = newll; Line Loop(ll) = {lb[]};
	surf = news;  Plane Surface(surf) = {ll};
	allSurf[2*t+1] = surf;
EndFor

sl = newsl; Surface Loop(sl) = {allSurf[]};
Volume(1000) = {sl};
